@@ -1,5 +1,5 @@
-#!/usr/bin/python
-# -*- coding: <encoding name> -*-
+#!/usr/bin/python3
+# -*- coding: utf-8 -*-
 
 from pykafka.exceptions import KafkaException
 from pykafka.exceptions import ConsumerStoppedException
@@ -60,7 +60,7 @@ class ConsumerJob(Thread):
         self.__started__ = True
         try:
             self.__listen__()
-        except KafkaException as e:
+        except (Exception, KafkaException) as e:
             self.logger.exception("Exception from topic: "
                                   f"{self.__conf__.topic} : {type(e)} {e}")
 
